@@ -3,6 +3,7 @@ from typing import Dict, List, Optional, Type
 from uuid import UUID
 
 from fastapi import APIRouter, Depends, status
+from fractal_specifications.generic.specification import Specification
 from pydantic import BaseModel
 
 from fractal import Fractal
@@ -13,7 +14,6 @@ from fractal.contrib.tokens.fractal import DummyTokenRolesFractal
 from fractal.contrib.tokens.models import TokenPayload, TokenPayloadRoles
 from fractal.core.models import Model
 from fractal.core.services import Service
-from fractal.core.specifications.generic.specification import Specification
 from fractal.core.utils.application_context import ApplicationContext
 from fractal.core.utils.settings import Settings
 
@@ -128,7 +128,9 @@ class BasicRestRouterService(DefaultRestRouterService):
         _entity = contract.to_entity(
             user_id=kwargs.get("sub"), account_id=kwargs.get("account")
         )
-        return self.ingress_service.add(_entity, str(kwargs.get("sub")), specification=specification)
+        return self.ingress_service.add(
+            _entity, str(kwargs.get("sub")), specification=specification
+        )
 
     def find_entities(
         self,
@@ -137,7 +139,9 @@ class BasicRestRouterService(DefaultRestRouterService):
         specification: Specification = None,
         **kwargs,
     ):
-        return self.ingress_service.find(str(kwargs.get("account")), q, specification=specification)
+        return self.ingress_service.find(
+            str(kwargs.get("account")), q, specification=specification
+        )
 
     def get_entity(
         self,
@@ -146,7 +150,9 @@ class BasicRestRouterService(DefaultRestRouterService):
         specification: Specification = None,
         **kwargs,
     ):
-        return self.ingress_service.get(str(entity_id), str(kwargs.get("account")), specification=specification)
+        return self.ingress_service.get(
+            str(entity_id), str(kwargs.get("account")), specification=specification
+        )
 
     def update_entity(
         self,
@@ -157,7 +163,9 @@ class BasicRestRouterService(DefaultRestRouterService):
         **kwargs,
     ):
         if _entity := self.get_entity(entity_id, specification=specification, **kwargs):
-            _entity = _entity.update(contract.dict())
+            _entity = _entity.update(
+                {k: v for k, v in contract.dict().items() if v is not None}
+            )
         else:
             _entity = contract.to_entity(
                 id=entity_id,
@@ -176,7 +184,10 @@ class BasicRestRouterService(DefaultRestRouterService):
         **kwargs,
     ) -> Dict:
         self.ingress_service.delete(
-            str(entity_id), str(kwargs.get("sub")), str(kwargs.get("account")), specification=specification
+            str(entity_id),
+            str(kwargs.get("sub")),
+            str(kwargs.get("account")),
+            specification=specification,
         )
         return {}
 
