@@ -1,16 +1,19 @@
 from dataclasses import asdict
+from datetime import date
 from typing import Iterator, Optional
 
+from fractal_specifications.contrib.google_firestore.specifications import (
+    FirestoreSpecificationBuilder,
+)
+from fractal_specifications.generic.specification import Specification
 from google.cloud import firestore
 from google.cloud.firestore_v1 import Client
 
 from fractal import Settings
 from fractal.contrib.gcp import SettingsMixin
-from fractal.contrib.gcp.firestore.specifications import FirestoreSpecificationBuilder
 from fractal.core.exceptions import ObjectNotFoundException
 from fractal.core.repositories import Entity, Repository
 from fractal.core.repositories.sort_repository_mixin import SortRepositoryMixin
-from fractal.core.specifications.generic.specification import Specification
 
 
 def get_firestore_client(settings: Settings):
@@ -105,21 +108,10 @@ class FirestoreRepositoryMixin(SettingsMixin, Repository[Entity]):
         return True
 
 
-# class FirestoreDict(dict):
-#     def __init__(self, obj):
-#         for i, v in enumerate(obj):
-#             if type(v[1]) is Decimal:
-#                 obj[i] = (v[0], f"{v[1]:.2f}")
-#             if type(v[1]) is date:
-#                 obj[i] = (v[0], v[1].isoformat())
-#         super(FirestoreDict, self).__init__(obj)
-
-
 class FirestoreRepositoryDictMixin(FirestoreRepositoryMixin[Entity]):
     def add(self, entity: Entity) -> Entity:
         doc_ref = self.collection.document(entity.id)
-        # doc_ref.set(asdict(entity, dict_factory=FirestoreDict))
-        doc_ref.set(entity.asdict())
+        doc_ref.set(entity.asdict(skip_types=(date,)))
         return entity
 
     def update(self, entity: Entity, *, upsert=False) -> Entity:
@@ -127,8 +119,7 @@ class FirestoreRepositoryDictMixin(FirestoreRepositoryMixin[Entity]):
             doc_ref = self.collection.document(entity.id)
             doc = doc_ref.get()
             if doc.exists:
-                # doc_ref.set(asdict(entity, dict_factory=FirestoreDict))
-                doc_ref.set(entity.asdict())
+                doc_ref.set(entity.asdict(skip_types=(date,)))
             return entity
         return self.add(entity)
 
