@@ -27,11 +27,14 @@ def fastapi_app(settings):
 
 
 @pytest.fixture
-def fastapi_app_with_default_routes(fastapi_app, token_service_application_context, settings):
+def fastapi_app_with_default_routes(
+    fastapi_app, token_service_application_context, settings
+):
     from fractal.contrib.fastapi.routers.default import inject_default_routes
 
     fastapi_app.include_router(
-        inject_default_routes(token_service_application_context, settings), tags=["default"]
+        inject_default_routes(token_service_application_context, settings),
+        tags=["default"],
     )
     return fastapi_app
 
@@ -57,7 +60,10 @@ def failing_service_fastapi_client(
 
     token_service_application_context.install_service(failing_service_class)
 
-    fastapi_app.include_router(inject_default_routes(token_service_application_context, settings), tags=["default"])
+    fastapi_app.include_router(
+        inject_default_routes(token_service_application_context, settings),
+        tags=["default"],
+    )
 
     return TestClient(fastapi_app)
 
